@@ -186,6 +186,7 @@ def seed_keys(stage_name: str, config_path: str):
     return keys_path
 
 @pfunk.command()
+@click.option('--local_user', help='Specifies whether the user is local.', prompt=True, default=False)
 @click.option('--config_path', help='Configuration file path', default='pfunk.json')
 @click.option('--project_path', help='Project module path')
 @click.option('--username', prompt=True, help='Username')
@@ -196,7 +197,7 @@ def seed_keys(stage_name: str, config_path: str):
 @click.option('--group_slug', prompt=True, help='User Group Slug', default=None)
 @click.argument('stage_name')
 def create_admin_user(stage_name: str, group_slug: str, last_name: str, first_name: str, email: str, password: str, username: str,
-                      project_path: str, config_path: str):
+                      project_path: str, config_path: str, local_user: bool):
     """
     Create an admin user in the project's Fauna user collection.
     Args:
@@ -209,6 +210,7 @@ def create_admin_user(stage_name: str, group_slug: str, last_name: str, first_na
         username: Username for the user
         project_path: Project path
         config_path: Config path
+        local_user: Specifies whether to create the user locally.
 
     Returns:
 
@@ -216,7 +218,8 @@ def create_admin_user(stage_name: str, group_slug: str, last_name: str, first_na
     config = load_config_file(config_path)
     secret = config['stages'][stage_name]['fauna_secret']
     User = import_util('pfunk.contrib.auth.collections.User')
-    os.environ['FAUNA_SECRET'] = secret
+    if not local_user:
+        os.environ['FAUNA_SECRET'] = secret
 
     user = User.create(
         username=username,
